@@ -4,11 +4,10 @@ import pathlib
 from enum import Enum
 from typing import Any, Dict, Iterable, List, Optional, Set, Union
 
-import orjson
 import requests
 
 from robotoff import settings
-from robotoff.utils import get_logger, http_session
+from robotoff.utils import get_logger, http_session, load_json
 from robotoff.utils.cache import CachedStore
 from robotoff.utils.types import JSONType
 
@@ -230,9 +229,7 @@ class Taxonomy:
 
     @classmethod
     def from_json(cls, file_path: Union[str, pathlib.Path]):
-        with open(str(file_path), "rb") as f:
-            data = orjson.loads(f.read())
-            return cls.from_dict(data)
+        return cls.from_dict(load_json(file_path, compressed=True))  # type: ignore
 
     def to_graph(self):
         """Generate a networkx.DiGraph from the taxonomy."""
@@ -305,28 +302,32 @@ TAXONOMY_STORES: Dict[str, CachedStore] = {
             fetch_taxonomy,
             url=settings.TAXONOMY_CATEGORY_URL,
             fallback_path=settings.TAXONOMY_CATEGORY_PATH,
-        )
+        ),
+        expiration_interval=720,
     ),
     TaxonomyType.ingredient.name: CachedStore(
         functools.partial(
             fetch_taxonomy,
             url=settings.TAXONOMY_INGREDIENT_URL,
             fallback_path=settings.TAXONOMY_INGREDIENT_PATH,
-        )
+        ),
+        expiration_interval=720,
     ),
     TaxonomyType.label.name: CachedStore(
         functools.partial(
             fetch_taxonomy,
             url=settings.TAXONOMY_LABEL_URL,
             fallback_path=settings.TAXONOMY_LABEL_PATH,
-        )
+        ),
+        expiration_interval=720,
     ),
     TaxonomyType.brand.name: CachedStore(
         functools.partial(
             fetch_taxonomy,
             url=settings.TAXONOMY_BRAND_URL,
             fallback_path=settings.TAXONOMY_BRAND_PATH,
-        )
+        ),
+        expiration_interval=720,
     ),
 }
 
@@ -375,6 +376,16 @@ UNPREFIXED_MAPPING_STORE: Dict[str, CachedStore] = {
 
 
 def match_unprefixed_value(value_tag: str, taxonomy_type: str) -> Optional[str]:
+    """From an unprefixed `value_tag`, return the taxonomized value in the
+    taxonomy (if any) or return None if no match was found.
+
+    Currently this only works for labels and brands:
+    - for label, from unprefixed `value_tag` (ex: en-organic), we return the
+    prefixed label (ex: en:eu-organic)
+    - for brand, we return the correctly capitalize brand name
+    (ex: carrefour-bio -> Carrefour Bio), as Product Opener does not have a
+    brand taxonomy so far
+    """
     unprefixed_mapping_cache = UNPREFIXED_MAPPING_STORE.get(taxonomy_type)
 
     if unprefixed_mapping_cache is None:
@@ -382,3 +393,20 @@ def match_unprefixed_value(value_tag: str, taxonomy_type: str) -> Optional[str]:
 
     unprefixed_mapping = unprefixed_mapping_cache.get()
     return unprefixed_mapping.get(value_tag)
+
+
+def match_taxonomized_value(value_tag: str, taxonomy_type: str) -> Optional[str]:
+    """Return the taxonomized value of a `value_tag` (if any) or return
+    None if no match was found.
+
+    Currently it only works for brand and label.
+    """
+    if taxonomy_type not in (TaxonomyType.brand.name, TaxonomyType.label.name):
+        return None
+
+    taxonomy = get_taxonomy(taxonomy_type)
+
+    if value_tag in taxonomy:
+        return value_tag
+
+    return match_unprefixed_value(value_tag, taxonomy_type)
